@@ -57,6 +57,7 @@ class GroupShape(ShapeBase):
         'shapes': 'ResourceUri',
         'fill_format': 'FillFormat',
         'effect_format': 'EffectFormat',
+        'three_d_format': 'ThreeDFormat',
         'line_format': 'LineFormat',
         'type': 'str'
     }
@@ -76,6 +77,7 @@ class GroupShape(ShapeBase):
         'shapes': 'shapes',
         'fill_format': 'fillFormat',
         'effect_format': 'effectFormat',
+        'three_d_format': 'threeDFormat',
         'line_format': 'lineFormat',
         'type': 'type'
     }
@@ -84,9 +86,9 @@ class GroupShape(ShapeBase):
         'type': 'GroupShape',
     }
 
-    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='GroupShape'):  # noqa: E501
+    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, three_d_format=None, line_format=None, type='GroupShape'):  # noqa: E501
         """GroupShape - a model defined in Swagger"""  # noqa: E501
-        super(GroupShape, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type)
+        super(GroupShape, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, three_d_format, line_format, type)
         self.type = 'GroupShape'
 
     def to_dict(self):
