@@ -44,6 +44,8 @@ class SwfExportOptions(ExportOptions):
     """
     swagger_types = {
         'default_regular_font': 'str',
+        'height': 'int',
+        'width': 'int',
         'format': 'str',
         'show_hidden_slides': 'bool',
         'compressed': 'bool',
@@ -69,6 +71,8 @@ class SwfExportOptions(ExportOptions):
 
     attribute_map = {
         'default_regular_font': 'defaultRegularFont',
+        'height': 'height',
+        'width': 'width',
         'format': 'format',
         'show_hidden_slides': 'showHiddenSlides',
         'compressed': 'compressed',
@@ -96,9 +100,9 @@ class SwfExportOptions(ExportOptions):
         'format': 'swf',
     }
 
-    def __init__(self, default_regular_font=None, format='swf', show_hidden_slides=None, compressed=None, viewer_included=None, show_page_border=None, show_full_screen=None, show_page_stepper=None, show_search=None, show_top_pane=None, show_bottom_pane=None, show_left_pane=None, start_open_left_pane=None, enable_context_menu=None, logo_image=None, logo_link=None, jpeg_quality=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, height=None, width=None, format='swf', show_hidden_slides=None, compressed=None, viewer_included=None, show_page_border=None, show_full_screen=None, show_page_stepper=None, show_search=None, show_top_pane=None, show_bottom_pane=None, show_left_pane=None, start_open_left_pane=None, enable_context_menu=None, logo_image=None, logo_link=None, jpeg_quality=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
         """SwfExportOptions - a model defined in Swagger"""  # noqa: E501
-        super(SwfExportOptions, self).__init__(default_regular_font, format)
+        super(SwfExportOptions, self).__init__(default_regular_font, height, width, format)
 
         self._show_hidden_slides = None
         self._compressed = None
@@ -122,29 +126,46 @@ class SwfExportOptions(ExportOptions):
         self._show_comments_by_no_author = None
         self.format = 'swf'
 
-        self.show_hidden_slides = show_hidden_slides
-        self.compressed = compressed
-        self.viewer_included = viewer_included
-        self.show_page_border = show_page_border
-        self.show_full_screen = show_full_screen
-        self.show_page_stepper = show_page_stepper
-        self.show_search = show_search
-        self.show_top_pane = show_top_pane
-        self.show_bottom_pane = show_bottom_pane
-        self.show_left_pane = show_left_pane
-        self.start_open_left_pane = start_open_left_pane
-        self.enable_context_menu = enable_context_menu
+        if show_hidden_slides is not None:
+            self.show_hidden_slides = show_hidden_slides
+        if compressed is not None:
+            self.compressed = compressed
+        if viewer_included is not None:
+            self.viewer_included = viewer_included
+        if show_page_border is not None:
+            self.show_page_border = show_page_border
+        if show_full_screen is not None:
+            self.show_full_screen = show_full_screen
+        if show_page_stepper is not None:
+            self.show_page_stepper = show_page_stepper
+        if show_search is not None:
+            self.show_search = show_search
+        if show_top_pane is not None:
+            self.show_top_pane = show_top_pane
+        if show_bottom_pane is not None:
+            self.show_bottom_pane = show_bottom_pane
+        if show_left_pane is not None:
+            self.show_left_pane = show_left_pane
+        if start_open_left_pane is not None:
+            self.start_open_left_pane = start_open_left_pane
+        if enable_context_menu is not None:
+            self.enable_context_menu = enable_context_menu
         if logo_image is not None:
             self.logo_image = logo_image
         if logo_link is not None:
             self.logo_link = logo_link
-        self.jpeg_quality = jpeg_quality
-        self.notes_position = notes_position
-        self.comments_position = comments_position
-        self.comments_area_width = comments_area_width
+        if jpeg_quality is not None:
+            self.jpeg_quality = jpeg_quality
+        if notes_position is not None:
+            self.notes_position = notes_position
+        if comments_position is not None:
+            self.comments_position = comments_position
+        if comments_area_width is not None:
+            self.comments_area_width = comments_area_width
         if comments_area_color is not None:
             self.comments_area_color = comments_area_color
-        self.show_comments_by_no_author = show_comments_by_no_author
+        if show_comments_by_no_author is not None:
+            self.show_comments_by_no_author = show_comments_by_no_author
 
     @property
     def show_hidden_slides(self):
